@@ -7,7 +7,7 @@ Command Line Interface
 """
 
 from ..amqp_worker import process, Worker
-
+from ..bluebase_check import check_trans
 
 from . import app
 
@@ -38,6 +38,11 @@ def async_daemon(queue, workers):
             thread.start()
 
 
+@cmd.command()
+def check_activation():
+    check_trans()
+
+
 @cmd.command()
 @click.option('--host', default='127.0.0.1')
 @click.option('--port', default=5000)
